/****************************************************************************

   Copyright (C) 1995 University of Utah

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the Free
   Software Foundation, 675 Massachusetts Avenue, Cambridge, MA 02139 USA;
   either version 1, or (at your option) any later version.

   The University of Utah disclaims all warranties with regard to this
   software, including all implied warranties of merchantability and fitness.
   In no event shall the University of Utah be liable for any special, indirect
   or consequential damages or any damages whatsoever resulting from loss of
   use, data or profits, whether in an action of contract, negligence or other
   tortious action, arising out of or in connection with the use or performance
   of this software.

*****************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "comm.h"
#include "server.h"


const char *help_string =
"Hamlet is designed as an external viewer for Web browsers.  It interprets\n"
"the contents of \".hamlet\" URLs by sending commands to other X windows\n"
"and automatically unpacking tar files.  It expects as its single command\n"
"line argument the name of a file containing a Hamlet directive.\n";


/* This is the "hamlet" external viewer.  It interprets ".hamlet" URLs.  If the
   first argument on the command line is "-help", a help string is printed to
   the standard output.  Otherwise, it expects a single command line argument,
   which must be the name of a file containing a hamlet directive. */

main (int argc, char *argv[]) {

    /* Print out the help string if requested. */

    if ((argc > 1) && strcmp(argv[1], "-help") == 0) {
	printf(help_string);
	exit(0);
    }


    if ((argc > 1) && strcmp(argv[1], "-version") == 0) {
	printf("Version 2.0\n");
	exit(0);
    }

    /* Make sure that we have access to the X display.  If not, there's
       no point proceeding.  This call will exit with an error message
       if it fails. */

    Communicator comm;


    /* Make sure that we have exactly one command line argument. */

    if (argc != 2) {
	char number[50];
	sprintf(number, "%d", argc-1);
	notifyUser("Hamlet expects exactly one argument, but was\n"
		   "given ", number, ".  Your \".mailcap\" file may be wrong");
	exit(1);
    }


    /* Obtain the file to work on. */

    FILE *file = fopen(argv[1], "r");
    if (!file) {
	notifyUser("Unable to read Hamlet command file \"", argv[1], "\"");
	exit(1);
    }


    /* Deal with the command. */

    processButton(file, comm, argv[1]);
    fclose(file);
    exit(0);

}
